@@ -52,3 +52,10 @@ TASK_STATUS_DESCRIPTION = {
 
 TASK_END_STATUS_CODE_LIST = ['10', '20', '23', '25', '30', '35', '45']
 
+TRANSFER_LOG = "RAYVISION_LOG"
+RAYVISION_DB = "RAYVISION_DB"
+
+WINDOWS_LOCAL_ENV = "USERPROFILE"
+LINUX_LOCAL_ENV = "HOME"
+RENDERFARM_SDK = "renderfarm_sdk"
+
